@@ -34,6 +34,7 @@ class Deployer(object):
         self.jinja = Environment(loader=FileSystemLoader(script_dir))
         self.project_name = name
         self.environment = environment
+        os.environ["ENVIRONMENT"] = environment
         self.docker = docker
         self.local = local
         self.subdomain = subdomain
@@ -274,6 +275,7 @@ class Deployer(object):
             ".aws-sam/build/template.yml",
             "--parameter-overrides",
             f"ENVIRONMENT={self.environment}",
+            "--no-fail-on-empty-changeset",
         ]
         if len(overrides) > 0:
             sam_deploy.append(",".join(overrides))
