@@ -23,6 +23,7 @@ def lambdahandler(func):
     module = func.__module__
     handler_name = f"{func.__name__}Handler"
     setattr(sys.modules[module], handler_name, func.get_handler())
+    func.is_lambda = True
     return func
 
 
@@ -30,6 +31,10 @@ class QueueFunction(LambdaFunction):
     pass
 
 
+class ScheduleFunction(LambdaFunction):
+    pass
+
+
 # def queuetrigger(queue):
 #     """
 #     Used to decorate a LambdaFunction to define an SQS trigger during deployment.
